Module: Snapi::Capability

Defined in:
lib/snapi/capability.rb

Overview

This class is exists as a way of definining an API capability using a handy DSL to define functions, their arguments, arity, validations and return types.

Defined Under Namespace

Modules: ClassMethods

Class Method Summary collapse

Class Method Details

.included(klass) ⇒ Object

When this module is included into a given Class this will wbe run. It will extend the clas with the methods found in the the Snapi::Capability::ClassMethods module and register the class in question with the Snapi module.



14
15
16
17
# File 'lib/snapi/capability.rb', line 14

def self.included(klass)
  klass.extend(ClassMethods)
  Snapi.register_capability(klass)
end